==> static_postgres_orm-0.0.1-dev.2.tar.gz: test/orm_product_test.dart <==
import 'package:test/test.dart';
import '../example/static_postgres_orm_example.dart';
import 'package:static_postgres_orm/static_postgres_orm.dart';

void main() async {
  var _postgresConnection = Postgres_SqlConnection(
      'localhost', 5432, 'db_teste', 'andriws', 'admserver01');
  _postgresConnection.className = 'tester';

  var product = Product_ORM(_postgresConnection);

  group('Product_ORM', () {
    group('Empty Database', () {
      test('-preparation', () async {
        var value = (await _postgresConnection.executeCommand(
                'delete', 'delete from product'))
            .isRight();
        expect(value, equals(true));
      });

      test('-deleteRecord', () async {
        var value = (await product.deleteRecord(1, 1))
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('record not found'));
      });

      test('-delete', () async {
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        var value = (await product.delete())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('record not found'));
      });

      test('-update', () async {
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        product.description.setValue('value');
        var value = (await product.update())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('record not found'));
      });

      test('-materialize', () async {
        var value = (await product.materialize(1, 1))
            .fold((l) => l.errorMessage.first, (r) => r.result);
        expect(value, equals('record not found'));
      });

      test('-insert', () async {
        product.clear();
        product.company_id.setValue(1);
        product.product_id.setValue(1);

        var value =
            (await product.insert()).fold((l) => l.result, (r) => r.result);
        expect(value, equals(true));
      });
    });

    group('Database with Two Records', () {
      test('-preparation1', () async {
        var value = (await _postgresConnection.executeCommand(
                'delete', 'delete from product'))
            .isRight();
        expect(value, equals(true));
      });

      test('-preparation2', () async {
        var value = (await _postgresConnection.executeCommand('delete',
                'insert into product(company_id,product_id) values(1,1)'))
            .isRight();
        expect(value, equals(true));
      });

      test('-update Succes', () async {
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        product.description.setValue('teste1');
        var value = (await product.update())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals(1));
      });

      test('-update Error', () async {
        product.company_id.setValue(3);
        product.product_id.setValue(3);
        product.description.setValue('teste1');
        var value = (await product.update())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('record not found'));
      });

      test('-materialize Error', () async {
        var value = (await product.materialize(2, 2))
            .fold((l) => l.errorMessage.first, (r) => r.rowsSelected);
        expect(value, equals('record not found'));
      });

      test('-materialize Succes', () async {
        var value = (await product.materialize(1, 1))
            .fold((l) => l.errorMessage.first, (r) => r.rowsSelected);
        expect(value, equals(1));
      });

      test('-deleteRecord Error', () async {
        var value = (await product.deleteRecord(3, 3))
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('record not found'));
      });

      test('-deleteRecord Succes', () async {
        var value = (await product.deleteRecord(1, 1))
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals(1));
      });

      test('-insert', () async {
        product.clear();
        product.company_id.setValue(1);
        product.product_id.setValue(1);

        var value =
            (await product.insert()).fold((l) => l.result, (r) => r.result);
        expect(value, equals(true));
      });

      test('-delete Succes', () async {
        var value = (await product.delete())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals(1));
      });

      test('-delete Error', () async {
        var value = (await product.delete())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('O campo company_id é obrigatório'));
      });
    });

    group('Duo', () {
      test('-preparation', () async {
        var value = (await _postgresConnection.executeCommand(
                'delete', 'delete from product'))
            .isRight();
        expect(value, equals(true));
      });

      test('-materialize', () async {
        var x = <bool>[];
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        x.add((await product.insert()).isRight());
        product.clear();
        x.add((await product.materialize(1, 1)).isRight());
        x.add((await product.materialize(1, 1)).isRight());
        var value = product.count;

        expect(value, equals(1));
        expect(x, equals([true, true, true]));
      });

      test('-insert', () async {
        var x = <bool>[];
        product.company_id.setValue(1);
        product.product_id.setValue(2);
        x.add((await product.insert()).isRight());
        x.add((await product.insert()).isRight());
        var value = product.count;

        expect(value, equals(2));
        expect(x, equals([true, false]));
      });

      test('-update', () async {
        var x = <bool>[];
        product.description.setValue('duo teste');
        x.add((await product.update()).isRight());
        product.description.setValue('duo teste');
        x.add((await product.update()).isRight());
        var value = product.count;

        expect(value, equals(2));
        expect(x, equals([true, true]));
      });

      test('-delete', () async {
        var x = <bool>[];

        x.add((await product.delete()).isRight());
        x.add((await product.delete()).isRight());
        x.add((await product.delete()).isRight());
        var value = product.count;

        expect(value, equals(0));
        expect(x, equals([true, true, false]));
      });

      test('-deleteRecord', () async {
        var x = <bool>[];
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        x.add((await product.insert()).isRight());
        product.company_id.setValue(2);
        product.product_id.setValue(2);
        x.add((await product.insert()).isRight());
        var value1 = product.count;
        product.clear();
        x.add((await product.deleteRecord(2, 2)).isRight());
        x.add((await product.deleteRecord(2, 2)).isRight());
        var value2 = product.count;

        expect(value1, equals(2));
        expect(value2, equals(0));
        expect(x, equals([true, true, true, false]));
      });
    });

    group('Handling Changes', () {
      test('-preparation', () async {
        var value = (await _postgresConnection.executeCommand(
                'delete', 'delete from product'))
            .isRight();
        expect(value, equals(true));
      });

      test('-materialize', () async {
        var x = <dynamic>[];
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        x.add((await product.insert()).isRight());
        product.clear();
        x.add((await product.materialize(1, 1)).isRight());
        product.clear();
        x.add((await product.materialize(1, 1)).isRight());
        product.company_id.setValue(1);
        product.product_id.setValue(55);
        x.add(product.count);
        product.cancelChanges();
        x.add(product.count);
        expect(x, equals([true, true, true, 1, 1]));
      });

      test('-update', () async {
        var x = <dynamic>[];
        product.company_id.setValue(1);
        product.product_id.setValue(55);
        x.add((await product.update()).isRight());
        product.cancelChanges();
        x.add((await product.update()).isRight());
        x.add(product.count);
        expect(x, equals([false, true, 1]));
      });

      test('-delete', () async {
        var x = <dynamic>[];
        product.company_id.setValue(1);
        product.product_id.setValue(55);
        x.add((await product.delete()).isRight());
        product.cancelChanges();
        x.add((await product.delete()).isRight());
        x.add(product.count);
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        x.add((await product.insert()).isRight());
        x.add(product.count);
        expect(x, equals([false, true, 0, true, 1]));
      });

      test('-deleteRecord', () async {
        var x = <dynamic>[];
        product.company_id.setValue(1);
        product.product_id.setValue(55);
        x.add((await product.deleteRecord(1, 1)).isRight());
        product.company_id.setValue(1);
        product.product_id.setValue(56);
        x.add((await product.deleteRecord(55, 55)).isRight());
        x.add(product.count);
        expect(x, equals([true, false, 0]));
      });
    });
  });
}

==> static_postgres_orm-0.0.2-dev.tar.gz: test/orm_product_test.dart <==
import 'package:test/test.dart';
import '../example/static_postgres_orm_example.dart';
import 'package:static_postgres_orm/static_postgres_orm.dart';

void main() async {
  var _postgresConnection = Postgres_SqlConnection(
      'localhost', 5432, 'db_teste', 'andriws', 'admserver01');
  _postgresConnection.className = 'tester';

  var product = Public_Product_ORM(_postgresConnection);

  group('Product_ORM', () {
    group('Empty Database', () {
      test('-preparation', () async {
        var value = (await _postgresConnection.executeCommand(
                'delete', 'delete from product'))
            .isRight();
        expect(value, equals(true));
      });

      test('-deleteRecord', () async {
        var value = (await product.deleteRecord(1, 1))
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('record not found'));
      });

      test('-delete', () async {
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        var value = (await product.delete())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('record not found'));
      });

      test('-update', () async {
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        product.description.setValue('value');
        var value = (await product.update())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('record not found'));
      });

      test('-materialize', () async {
        var value = (await product.materialize(1, 1))
            .fold((l) => l.errorMessage.first, (r) => r.result);
        expect(value, equals('record not found'));
      });

      test('-insert', () async {
        product.clear();
        product.company_id.setValue(1);
        product.product_id.setValue(1);

        var value =
            (await product.insert()).fold((l) => l.result, (r) => r.result);
        expect(value, equals(true));
      });
    });

    group('Database with Two Records', () {
      test('-preparation1', () async {
        var value = (await _postgresConnection.executeCommand(
                'delete', 'delete from product'))
            .isRight();
        expect(value, equals(true));
      });

      test('-preparation2', () async {
        var value = (await _postgresConnection.executeCommand('delete',
                'insert into product(company_id,product_id) values(1,1)'))
            .isRight();
        expect(value, equals(true));
      });

      test('-update Succes', () async {
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        product.description.setValue('teste1');
        var value = (await product.update())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals(1));
      });

      test('-update Error', () async {
        product.company_id.setValue(3);
        product.product_id.setValue(3);
        product.description.setValue('teste1');
        var value = (await product.update())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('record not found'));
      });

      test('-materialize Error', () async {
        var value = (await product.materialize(2, 2))
            .fold((l) => l.errorMessage.first, (r) => r.rowsSelected);
        expect(value, equals('record not found'));
      });

      test('-materialize Succes', () async {
        var value = (await product.materialize(1, 1))
            .fold((l) => l.errorMessage.first, (r) => r.rowsSelected);
        expect(value, equals(1));
      });

      test('-deleteRecord Error', () async {
        var value = (await product.deleteRecord(3, 3))
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('record not found'));
      });

      test('-deleteRecord Succes', () async {
        var value = (await product.deleteRecord(1, 1))
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals(1));
      });

      test('-insert', () async {
        product.clear();
        product.company_id.setValue(1);
        product.product_id.setValue(1);

        var value =
            (await product.insert()).fold((l) => l.result, (r) => r.result);
        expect(value, equals(true));
      });

      test('-delete Succes', () async {
        var value = (await product.delete())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals(1));
      });

      test('-delete Error', () async {
        var value = (await product.delete())
            .fold((l) => l.errorMessage.first, (r) => r.rowsAffected);
        expect(value, equals('O campo company_id é obrigatório'));
      });
    });

    group('Duo', () {
      test('-preparation', () async {
        var value = (await _postgresConnection.executeCommand(
                'delete', 'delete from product'))
            .isRight();
        expect(value, equals(true));
      });

      test('-materialize', () async {
        var x = <bool>[];
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        x.add((await product.insert()).isRight());
        product.clear();
        x.add((await product.materialize(1, 1)).isRight());
        x.add((await product.materialize(1, 1)).isRight());
        var value = product.count;

        expect(value, equals(1));
        expect(x, equals([true, true, true]));
      });

      test('-insert', () async {
        var x = <bool>[];
        product.company_id.setValue(1);
        product.product_id.setValue(2);
        x.add((await product.insert()).isRight());
        x.add((await product.insert()).isRight());
        var value = product.count;

        expect(value, equals(2));
        expect(x, equals([true, false]));
      });

      test('-update', () async {
        var x = <bool>[];
        product.description.setValue('duo teste');
        x.add((await product.update()).isRight());
        product.description.setValue('duo teste');
        x.add((await product.update()).isRight());
        var value = product.count;

        expect(value, equals(2));
        expect(x, equals([true, true]));
      });

      test('-delete', () async {
        var x = <bool>[];

        x.add((await product.delete()).isRight());
        x.add((await product.delete()).isRight());
        x.add((await product.delete()).isRight());
        var value = product.count;

        expect(value, equals(0));
        expect(x, equals([true, true, false]));
      });

      test('-deleteRecord', () async {
        var x = <bool>[];
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        x.add((await product.insert()).isRight());
        product.company_id.setValue(2);
        product.product_id.setValue(2);
        x.add((await product.insert()).isRight());
        var value1 = product.count;
        product.clear();
        x.add((await product.deleteRecord(2, 2)).isRight());
        x.add((await product.deleteRecord(2, 2)).isRight());
        var value2 = product.count;

        expect(value1, equals(2));
        expect(value2, equals(0));
        expect(x, equals([true, true, true, false]));
      });
    });

    group('Handling Changes', () {
      test('-preparation', () async {
        var value = (await _postgresConnection.executeCommand(
                'delete', 'delete from product'))
            .isRight();
        expect(value, equals(true));
      });

      test('-materialize', () async {
        var x = <dynamic>[];
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        x.add((await product.insert()).isRight());
        product.clear();
        x.add((await product.materialize(1, 1)).isRight());
        product.clear();
        x.add((await product.materialize(1, 1)).isRight());
        product.company_id.setValue(1);
        product.product_id.setValue(55);
        x.add(product.count);
        product.cancelChanges();
        x.add(product.count);
        expect(x, equals([true, true, true, 1, 1]));
      });

      test('-update', () async {
        var x = <dynamic>[];
        product.company_id.setValue(1);
        product.product_id.setValue(55);
        x.add((await product.update()).isRight());
        product.cancelChanges();
        x.add((await product.update()).isRight());
        x.add(product.count);
        expect(x, equals([false, true, 1]));
      });

      test('-delete', () async {
        var x = <dynamic>[];
        product.company_id.setValue(1);
        product.product_id.setValue(55);
        x.add((await product.delete()).isRight());
        product.cancelChanges();
        x.add((await product.delete()).isRight());
        x.add(product.count);
        product.company_id.setValue(1);
        product.product_id.setValue(1);
        x.add((await product.insert()).isRight());
        x.add(product.count);
        expect(x, equals([false, true, 0, true, 1]));
      });

      test('-deleteRecord', () async {
        var x = <dynamic>[];
        product.company_id.setValue(1);
        product.product_id.setValue(55);
        x.add((await product.deleteRecord(1, 1)).isRight());
        product.company_id.setValue(1);
        product.product_id.setValue(56);
        x.add((await product.deleteRecord(55, 55)).isRight());
        x.add(product.count);
        expect(x, equals([true, false, 0]));
      });
    });
  });
}
